@@ -1,7 +1,7 @@
 #' @title `r lifecycle::badge("experimental")` Create a controller with a
 #'   LSF launcher.
 #' @export
-#' @family controllers
+#' @family plugin_lsf
 #' @description Create an `R6` object to submit tasks and
 #'   launch workers on LSF workers.
 #' @details WARNING: the `crew.cluster` LSF plugin is experimental
@@ -46,7 +46,8 @@ crew_controller_lsf <- function(
   launch_max = 5L,
   verbose = FALSE,
   command_submit = as.character(Sys.which("bsub")),
-  command_delete = as.character(Sys.which("bkill")),
+  command_terminate = as.character(Sys.which("bkill")),
+  command_delete = NULL,
   script_directory = tempdir(),
   script_lines = character(0L),
   lsf_cwd = getwd(),
@@ -77,6 +78,8 @@ crew_controller_lsf <- function(
   )
   launcher <- crew_launcher_lsf(
     name = name,
+    seconds_interval = seconds_interval,
+    seconds_timeout = seconds_timeout,
     seconds_launch = seconds_launch,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
@@ -90,6 +93,7 @@ crew_controller_lsf <- function(
     tls = tls,
     verbose = verbose,
     command_submit = command_submit,
+    command_terminate = command_terminate,
     command_delete = command_delete,
     script_directory = script_directory,
     script_lines = script_lines,
