@@ -42,7 +42,8 @@ crew_controller_pbs <- function(
   launch_max = 5L,
   verbose = FALSE,
   command_submit = as.character(Sys.which("qsub")),
-  command_delete = as.character(Sys.which("qdel")),
+  command_terminate = as.character(Sys.which("qdel")),
+  command_delete = NULL,
   script_directory = tempdir(),
   script_lines = character(0L),
   pbs_cwd = TRUE,
@@ -89,6 +90,7 @@ crew_controller_pbs <- function(
     tls = tls,
     verbose = verbose,
     command_submit = command_submit,
+    command_terminate = command_terminate,
     command_delete = command_delete,
     script_directory = script_directory,
     script_lines = script_lines,
