@@ -46,7 +46,8 @@ crew_controller_slurm <- function(
   launch_max = 5L,
   verbose = FALSE,
   command_submit = as.character(Sys.which("sbatch")),
-  command_delete = as.character(Sys.which("scancel")),
+  command_terminate = as.character(Sys.which("scancel")),
+  command_delete = NULL,
   script_directory = tempdir(),
   script_lines = character(0L),
   slurm_log_output = "/dev/null",
@@ -92,6 +93,7 @@ crew_controller_slurm <- function(
     tls = tls,
     verbose = verbose,
     command_submit = command_submit,
+    command_terminate = command_terminate,
     command_delete = command_delete,
     script_directory = script_directory,
     script_lines = script_lines,
