@@ -77,7 +77,8 @@ crew_launcher_pbs <- function(
   tls = crew::crew_tls(mode = "automatic"),
   verbose = FALSE,
   command_submit = as.character(Sys.which("qsub")),
-  command_delete = as.character(Sys.which("qdel")),
+  command_terminate = as.character(Sys.which("qdel")),
+  command_delete = NULL,
   script_directory = tempdir(),
   script_lines = character(0L),
   pbs_cwd = TRUE,
@@ -89,6 +90,15 @@ crew_launcher_pbs <- function(
   pbs_walltime_hours = 12
 ) {
   name <- as.character(name %|||% crew::crew_random_name())
+  if (!is.null(command_delete)) {
+    crew::crew_deprecate(
+      name = "command_delete",
+      date = "2023-01-08",
+      version = "0.1.4.9001",
+      alternative = "command_terminate"
+    )
+    command_terminate <- command_delete
+  }
   launcher <- crew_class_launcher_pbs$new(
     name = name,
     seconds_interval = seconds_interval,
@@ -106,7 +116,7 @@ crew_launcher_pbs <- function(
     tls = tls,
     verbose = verbose,
     command_submit = command_submit,
-    command_delete = command_delete,
+    command_terminate = command_terminate,
     script_directory = script_directory,
     script_lines = script_lines,
     pbs_cwd = pbs_cwd,
@@ -189,7 +199,7 @@ crew_class_launcher_pbs <- R6::R6Class(
     #' @param tls See [crew_launcher_pbs()].
     #' @param verbose See [crew_launcher_pbs()].
     #' @param command_submit See [crew_launcher_pbs()].
-    #' @param command_delete See [crew_launcher_pbs()].
+    #' @param command_terminate See [crew_launcher_pbs()].
     #' @param script_directory See [crew_launcher_pbs()].
     #' @param script_lines See [crew_launcher_pbs()].
     #' @param pbs_cwd See [crew_launcher_sge()].
@@ -216,7 +226,7 @@ crew_class_launcher_pbs <- R6::R6Class(
       tls = NULL,
       verbose = NULL,
       command_submit = NULL,
-      command_delete = NULL,
+      command_terminate = NULL,
       script_directory = NULL,
       script_lines = NULL,
       pbs_cwd = NULL,
@@ -244,7 +254,7 @@ crew_class_launcher_pbs <- R6::R6Class(
         tls = tls,
         verbose = verbose,
         command_submit = command_submit,
-        command_delete = command_delete,
+        command_terminate = command_terminate,
         script_directory = script_directory,
         script_lines = script_lines
       )
