@@ -71,7 +71,8 @@ crew_launcher_slurm <- function(
   tls = crew::crew_tls(mode = "automatic"),
   verbose = FALSE,
   command_submit = as.character(Sys.which("sbatch")),
-  command_delete = as.character(Sys.which("scancel")),
+  command_terminate = as.character(Sys.which("scancel")),
+  command_delete = NULL,
   script_directory = tempdir(),
   script_lines = character(0L),
   slurm_log_output = "/dev/null",
@@ -82,6 +83,15 @@ crew_launcher_slurm <- function(
   slurm_partition = NULL
 ) {
   name <- as.character(name %|||% crew::crew_random_name())
+  if (!is.null(command_delete)) {
+    crew::crew_deprecate(
+      name = "command_delete",
+      date = "2023-01-08",
+      version = "0.1.4.9001",
+      alternative = "command_terminate"
+    )
+    command_terminate <- command_delete
+  }
   launcher <- crew_class_launcher_slurm$new(
     name = name,
     seconds_interval = seconds_interval,
@@ -99,7 +109,7 @@ crew_launcher_slurm <- function(
     tls = tls,
     verbose = verbose,
     command_submit = command_submit,
-    command_delete = command_delete,
+    command_terminate = command_terminate,
     script_directory = script_directory,
     script_lines = script_lines,
     slurm_log_output = slurm_log_output,
@@ -129,7 +139,10 @@ crew_class_launcher_slurm <- R6::R6Class(
     .slurm_memory_gigabytes_per_cpu = NULL,
     .slurm_cpus_per_task = NULL,
     .slurm_time_minutes = NULL,
-    .slurm_partition = NULL
+    .slurm_partition = NULL,
+    .args_terminate = function(name) {
+      c("--name", shQuote(name))
+    }
   ),
   active = list(
     #' @field slurm_log_output See [crew_launcher_slurm()].
@@ -176,7 +189,7 @@ crew_class_launcher_slurm <- R6::R6Class(
     #' @param tls See [crew_launcher_slurm()].
     #' @param verbose See [crew_launcher_slurm()].
     #' @param command_submit See [crew_launcher_sge()].
-    #' @param command_delete See [crew_launcher_sge()].
+    #' @param command_terminate See [crew_launcher_sge()].
     #' @param script_directory See [crew_launcher_sge()].
     #' @param script_lines See [crew_launcher_sge()].
     #' @param slurm_log_output See [crew_launcher_slurm()].
@@ -202,7 +215,7 @@ crew_class_launcher_slurm <- R6::R6Class(
       tls = NULL,
       verbose = NULL,
       command_submit = NULL,
-      command_delete = NULL,
+      command_terminate = NULL,
       script_directory = NULL,
       script_lines = NULL,
       slurm_log_output = NULL,
@@ -229,7 +242,7 @@ crew_class_launcher_slurm <- R6::R6Class(
         tls = tls,
         verbose = verbose,
         command_submit = command_submit,
-        command_delete = command_delete,
+        command_terminate = command_terminate,
         script_directory = script_directory,
         script_lines = script_lines
       )
@@ -340,14 +353,6 @@ crew_class_launcher_slurm <- R6::R6Class(
         ),
         private$.script_lines
       )
-    },
-    #' @description Worker termination arguments.
-    #' @return Character vector of arguments to the command that
-    #'   terminates a worker.
-    #' @param name Character of length 1, name of the job of the worker
-    #'   on the scheduler.
-    args_terminate = function(name) {
-      c("--name", shQuote(name))
     }
   )
 )
